Ext.define('Shopware.apps.QuiversConfiguration.view.tabs.General', {
    extend: 'Ext.form.Panel',
    alias: 'widget.quivers-configuration-tabs-general',
    title: 'Quivers Settings',

    anchor: '100%',
    border: false,
    bodyPadding: 10,

    style: {
        background: '#EBEDEF'
    },

    fieldDefaults: {
        anchor: '100%',
        labelWidth: 180
    },

    /**
     * @type { Ext.form.FieldSet }
     */
    restContainer: null,


    initComponent: function () {
        var me = this;

        me.items = me.createItems();

        me.callParent(arguments);

        // Manually set the background color of the toolbar.
        me.toolbarContainer.setBodyStyle(me.style);
    },

    /**
     * @returns { Array }
     */
    createItems: function () {
        var me = this;

        return [
            me.createSettings()
        ];
    },
    
    registerEvents: function () {
        var me = this;

        me.addEvents(
            /**
             * Will be fired when the user clicks on the save button
             */
            'saveQuiversSettings'
        );
    },

    createSettings: function () {
        var me = this;

        me.toolbarContainer = me.createToolbar();

        me.restContainer = Ext.create('Ext.form.FieldSet', {

            items: [
                {
                    xtype: 'textfield',
                    name: 'apiKey',
                    fieldLabel: 'Quivers Api Key',
                    allowBlank: false
                },
                {
                    xtype: 'textfield',
                    name: 'businessRefId',
                    fieldLabel: 'Business Ref Id',
                    allowBlank: false
                },
                {
                    xtype: 'textfield',
                    name: 'baseUrl',
                    fieldLabel: 'Shopware Base Url',
                    allowBlank: false
                },
                {
                    xtype: 'textfield',
                    name: 'basicAuth',
                    fieldLabel: 'Basic Auth',
                    allowBlank: false
                },
                {
                    xtype: 'checkbox',
                    name: 'sandbox',
                    inputValue: true,
                    uncheckedValue: false,
                    fieldLabel: 'Quivers Sandbox'
                },
                {
                    xtype: 'checkbox',
                    name: 'enablePlugin',
                    inputValue: true,
                    uncheckedValue: false,
                    fieldLabel: 'Enable Plugin'
                },
                me.toolbarContainer
            ]
        });

        return me.restContainer;   
    },

    createToolbar: function () {
        var me = this;

        return Ext.create('Ext.form.Panel', {
            dock: 'bottom',
            border: false,
            bodyPadding: 5,
            name: 'toolbarContainer',

            items: [{
                xtype: 'button',
                cls: 'primary',
                text: 'Save',
                style: {
                    float: 'right'
                },
                handler: Ext.bind(me.onSaveButtonClick, me)
            }]
        });
    },

    onSaveButtonClick: function () {
        var me = this;

        me.fireEvent('saveQuiversSettings');
    }
  
});
