Ext.define('Shopware.apps.QuiversConfiguration.view.tabs.QuiversTax', {
    extend: 'Ext.form.Panel',   
    alias: 'widget.quivers-configuration-tabs-quivers-tax',
    title: 'Quivers Tax Settings',

    anchor: '100%',
    border: false,
    bodyPadding: 10,

    style: {
        background: '#EBEDEF'
    },

    fieldDefaults: {
        anchor: '100%',
        labelWidth: 180
    },

    /**
     * @type { Ext.form.FieldSet }
     */
    restContainer: null,

     /**
     * @type { Ext.form.FieldSet }
     */
     claimingContainer:null,


    initComponent: function () {
        var me = this;

        me.marketPlaceStore = Ext.getStore('QuiversConfigurationMarketplaces') || Ext.create('Shopware.apps.QuiversConfiguration.store.Marketplaces');
        me.ClaimingGroupStore = Ext.getStore('QuiversConfigurationClaimingGroup') || Ext.create('Shopware.apps.QuiversConfiguration.store.ClaimingGroup');

        me.items = me.createItems();
        me.callParent(arguments);

        // Manually set the background color of the toolbar.
        me.toolbarContainer.setBodyStyle(me.style);

        me.marketPlaceStore.load();
        me.ClaimingGroupStore.load();

        me.marketPlaceStore.on('load', function(store) {
            var newObject = {};
            newObject.id = '';
            newObject.text = 'Select a MarketPlace';
            var exists = false;
            store.each(function(rec){
                id = rec.data.id;
                if(id == ''){
                    exists = true;
                }
            });
            if(exists){
                return;
            }
            store.insert(0, newObject);

            var allItems = me.restContainer.items.getRange();
            allItems.forEach(function(item) {
                item.setValue('');
            });
        });

        me.ClaimingGroupStore.on('load', function(store) {
            var newObject = {};
            newObject.id = '';
            newObject.text = 'Select claiming Group';
            var exists = false;
            store.each(function(rec){
                id = rec.data.id;
                if(id == ''){
                    exists = true;
                }
            });
            if(exists){
                return;
            }
            store.insert(0, newObject);

            var allItems = me.claimingContainer.items.getRange();
            allItems.forEach(function(item) {
                item.setValue('');
            });
        });
    },

    registerEvents: function () {
        var me = this;

        me.addEvents(
            /**
             * Will be fired when the user clicks on the save button
             */
            'saveTaxSettings',

            'toSaveTaxValues'
        );
    },
    /**
     * @returns { Array }
     */
    createItems: function () {
        var me = this;

        return [
            me.createSettings(),
            me.createClaimingGroup(),
            me.createToolbar()
        ];
    },

    createSettings: function () {
        var me = this;
        
        me.restContainer = Ext.create('Ext.form.FieldSet', {
            title: 'Marketplace Settings',

            items: [
                {
                    xtype: 'combobox',
                    name: 'USD_Marketplace',
                    fieldLabel: 'USD Marketplace',
                    queryMode: 'local',
                    store: me.marketPlaceStore,
                    editable: false,
                    valueField: 'id',
                    displayField: 'text',
                    id: 'USD_Marketplace',
                },
                {
                    xtype: 'combobox',
                    name: 'EUR_Marketplace',
                    fieldLabel: 'EUR Marketplace',
                    store: me.marketPlaceStore,
                    editable: false,
                    valueField: 'id',
                    queryMode: 'local',
                    displayField: 'text',
                },
                {
                    xtype: 'combobox',
                    name: 'AUD_Marketplace',
                    fieldLabel: 'AUD Marketplace',
                    editable: false,
                    store: me.marketPlaceStore,
                    valueField: 'id',
                    queryMode: 'local',
                    displayField: 'text',
                },
                {
                    xtype: 'combobox',
                    name: 'JPY_Marketplace',
                    fieldLabel: 'JPY Marketplace',
                    editable: false,
                    store: me.marketPlaceStore,
                    valueField: 'id',
                    queryMode: 'local',
                    displayField: 'text',
                },
                {
                    xtype: 'combobox',
                    name: 'GBP_Marketplace',
                    fieldLabel: 'GBP Marketplace',
                    store: me.marketPlaceStore,
                    valueField: 'id',
                    editable: false,
                    queryMode: 'local',
                    displayField: 'text',
                },
                {
                    xtype: 'combobox',
                    name: 'CAD_Marketplace',
                    fieldLabel: 'CAD Marketplace',
                    store: me.marketPlaceStore,
                    editable: false,
                    valueField: 'id',
                    queryMode: 'local',
                    displayField: 'text',
                }
            ]
        });

        return me.restContainer;   
    },

    createClaimingGroup: function () {
        var me = this;
        
        me.claimingContainer = Ext.create('Ext.form.FieldSet', {
            title: 'Claiming Group Settings',

            items: [
                {
                    xtype: 'combobox',
                    name: 'USD_Claiming',
                    fieldLabel: 'USD Claiming Group',
                    store: me.ClaimingGroupStore,
                    valueField: 'id',
                    editable: false,
                    queryMode: 'local',
                    displayField: 'text',
                    multiSelect:true,
                },
                {
                    xtype: 'combobox',
                    name: 'EUR_Claiming',
                    fieldLabel: 'EUR Claiming Group',
                    store: me.ClaimingGroupStore,
                    editable: false,
                    valueField: 'id',
                    queryMode: 'local',
                    displayField: 'text',
                    multiSelect:true,
                },
                {
                    xtype: 'combobox',
                    name: 'AUD_Claiming',
                    fieldLabel: 'AUD Claiming Group',
                    store: me.ClaimingGroupStore,
                    valueField: 'id',
                    multiSelect:true,
                    editable: false,
                    queryMode: 'local',
                    displayField: 'text',
                },
                {
                    xtype: 'combobox',
                    name: 'JPY_Claiming',
                    fieldLabel: 'JPY Claiming Group',
                    store: me.ClaimingGroupStore,
                    valueField: 'id',
                    queryMode: 'local',
                    editable: false,
                    displayField: 'text',
                    multiSelect:true,
                },
                {
                    xtype: 'combobox',
                    name: 'GBP_Claiming',
                    fieldLabel: 'GBP Claiming Group',
                    store: me.ClaimingGroupStore,
                    editable: false,
                    valueField: 'id',
                    queryMode: 'local',
                    displayField: 'text',
                    multiSelect:true,
                },
                {
                    xtype: 'combobox',
                    name: 'CAD_Claiming',
                    fieldLabel: 'CAD Claiming Group',
                    store: me.ClaimingGroupStore,
                    queryMode: 'local',
                    editable: false,
                    displayField: 'text',
                    valueField: 'id',
                    multiSelect:true,
                },
            ]
        });

        return me.claimingContainer;   
    },

    createToolbar: function () {
        var me = this;

        me.toolbarContainer = Ext.create('Ext.form.Panel', {
            dock: 'bottom',
            border: false,
            bodyPadding: 5,
            name: 'toolbarContainer',

            items: [{
                xtype: 'button',
                cls: 'primary',
                text: 'Save',
                style: {
                    float: 'right'
                },
                handler: Ext.bind(me.onSaveButtonClick, me, me.quivers_tax_settings)
            }]
        });
        return me.toolbarContainer;
    },

    onSaveButtonClick: function () {
        var me = this;

        me.fireEvent('saveTaxSettings');
    }
  
});
